pub struct AliasDuplicatedProjectionRewrite;Expand description
Rewrite rule for adding alias to duplicated projection
This rule is to deal with sql like SELECT n.oid, n.* FROM n, which is a
valid statement in postgres. But datafusion treat it as illegal because of
duplicated column oid in projection.
This rule will add alias to column, when there is a wildcard found in projection.