pub struct PostgresCompatibilityParser { /* private fields */ }Expand description
A parser with Postgres Compatibility for Datafusion
This parser will try its best to rewrite postgres SQL into a form that datafuiosn supports. It also maintains a blacklist that will transform the statement to a similar version if rewrite doesn’t worth the effort for now.
Implementations